IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeServer]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeServer]
GO

CREATE PROCEDURE dbo.VSE_UpgradeServer
(
	@PolicyObjectID INT
)
AS
BEGIN
	IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE NAME = '#VseTmpUpgradeServer')
	DROP TABLE #VseTmpUpgradeServer
	
	CREATE TABLE [dbo].[#VseTmpUpgradeServer] (
		[PolicySettingsID] [int] NOT NULL ,
		[PolicySettingsName] [nvarchar] (258) NULL ,
		[PolicyParamInt] [int] NULL ,
		[PolicyParamStr] [nvarchar] (256) NULL ,
		[PolicySectionName] [nvarchar] (128) NULL ,
		[PolicySettingName] [nvarchar] (128) NULL ,
		[PolicySettingValue] [nvarchar] (3072) NULL ,
		[PolicyTheTimestamp] [binary] (8) NULL ,
	)
	
	INSERT INTO #VseTmpUpgradeServer EXECUTE EPOPolicy_GetPolicyObjectSettingValues @PolicyObjectID

	DECLARE @PolicySettingsID INT
	DECLARE @PolicySectionName NVARCHAR(128)
	DECLARE @PolicySettingName NVARCHAR(128)
	DECLARE @PolicySettingValue NVARCHAR(3072)	
	DECLARE @PolicyCursor CURSOR

	SET @PolicyCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
		SELECT PolicySettingsID, PolicySectionName, PolicySettingName, PolicySettingValue FROM #VseTmpUpgradeServer
			
	OPEN @PolicyCursor
			
	FETCH NEXT FROM @PolicyCursor INTO @PolicySettingsID, @PolicySectionName, @PolicySettingName, @PolicySettingValue
	WHILE (@@FETCH_STATUS = 0)
	BEGIN
		IF LEFT(@PolicySectionName, LEN('Server_')) = 'Server_'
		BEGIN
			DECLARE @NewSectionName NVARCHAR(30)
			
			SET @NewSectionName = 'Wrkstn_' + RIGHT(@PolicySectionName, LEN(@PolicySectionName) - LEN('Server_'))
	
			EXECUTE EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @NewSectionName, @PolicySettingName, @PolicySettingValue
		END
	
		FETCH NEXT FROM @PolicyCursor INTO @PolicySettingsID, @PolicySectionName, @PolicySettingName, @PolicySettingValue
	END
	
	CLOSE @PolicyCursor
	DEALLOCATE @PolicyCursor
	
	IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE NAME = '#VseTmpUpgradeServer')
	DROP TABLE #VseTmpUpgradeServer
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_CreateServerPolicy]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_CreateServerPolicy]
GO

CREATE PROCEDURE dbo.VSE_CreateServerPolicy
(
	@PolicySettingsID INT,
	@PolicySettingsName NVARCHAR(256),
	@PolicySettingsTypeID NVARCHAR(256),
	@ProductCode NVARCHAR(50)
)
AS
BEGIN

	DECLARE @TypeTextID NVARCHAR(256)
	SELECT @TypeTextID = EPOPolicyTypes.TypeTextID
	FROM EPOPolicyTypes
	WHERE EPOPolicyTypes.TypeID = @PolicySettingsTypeID;

	DECLARE @PolicyObjectID INT
	SELECT @PolicyObjectID = EPOPolicyObjectToSettings.PolicyObjectID
	FROM EPOPolicyObjectToSettings
	WHERE EPOPolicyObjectToSettings.PolicySettingsID = @PolicySettingsID

	DECLARE @UserID INT
	SELECT @UserID = 0
	SELECT @UserID = UserID
	FROM EPOPolicyObjectUserRoles
	WHERE EPOPolicyObjectUserRoles.PolicyObjectID = @PolicyObjectID
	AND EPOPolicyObjectUserRoles.ACFlags = 1

	DECLARE @NewTypeID INT
	SELECT @NewTypeID = 0
	SELECT @NewTypeID = EPOPolicyTypes.TypeID
	FROM EPOPolicyTypes
	WHERE EPOPolicyTypes.TypeTextID = @TypeTextID
	AND EPOPolicyTypes.FeatureTextID = @ProductCode
	IF (@NewTypeID > 0)
	BEGIN
		DECLARE @NewPolicyObjectID INT
		DECLARE @NewPolicySettingsName NVARCHAR(256)
		SELECT @NewPolicySettingsName = @PolicySettingsName + '_Server'

		DECLARE @COUNT INT
		SELECT @COUNT = 1
		WHILE EXISTS(SELECT * FROM EPOPolicyObjects 
				WHERE EPOPolicyObjects.Name = @NewPolicySettingsName
				AND EPOPolicyObjects.TypeID = @NewTypeID)
		BEGIN
			SELECT @NewPolicySettingsName = @PolicySettingsName + '_Server.' + CAST(@COUNT AS NVARCHAR)
			SELECT @COUNT = @COUNT + 1
		END

		EXECUTE EPOPolicy_CopyPolicyObject 0, @PolicyObjectID, @NewPolicySettingsName, @UserID, 1, @NewPolicyObjectID OUTPUT	
		
		UPDATE EPOPolicyObjects
		SET TypeID = @NewTypeID
		WHERE PolicyObjectID = @NewPolicyObjectID

		DECLARE @NewPolicySettingsID INT
		SELECT @NewPolicySettingsID = EPOPolicyObjectToSettings.PolicySettingsID
		FROM EPOPolicyObjectToSettings
		WHERE EPOPolicyObjectToSettings.PolicyObjectID = @NewPolicyObjectID	
		UPDATE EPOPolicySettings
		SET TypeID = @NewTypeID
		WHERE PolicySettingsID = @NewPolicySettingsID		

        	EXECUTE VSE_UpgradeServer @NewPolicyObjectID
	END
END
GO

DECLARE @SoftwareID NVARCHAR(30)
SELECT @SoftwareID = 'VIRUSCAN8700'

DECLARE @DefaultPolicySettingsID INT
DECLARE @Value NVARCHAR(1024)

SELECT @DefaultPolicySettingsID = PolicySettingsID
	FROM EPOPolicySettings, EPOPolicyTypes
	WHERE EPOPolicyTypes.FeatureTextID = @SoftwareID
	AND EPOPolicyTypes.TypeTextID = 'VSC700_General_Policies'
	AND EPOPolicyTypes.TypeID = EPOPolicySettings.TypeID
	AND EPOPolicySettings.Name = 'McAfee Default'

EXEC EPOPolicy_GetPolicySettingValue @DefaultPolicySettingsID, 'ServerUpgraded', 'UpgradeHappened', @Value OUTPUT

IF @Value IS NULL
BEGIN	
	DECLARE @ProductCode NVARCHAR(30)
	
	SELECT @ProductCode = ''
	
	IF EXISTS (SELECT * FROM EPOPolicyTypes 
			WHERE FeatureTextID = @SoftwareID)
	BEGIN
		SELECT @ProductCode = @SoftwareID
	END
	
	IF @ProductCode <> ''
	BEGIN
		DECLARE @PolicyCursor CURSOR;
		SET @PolicyCursor = CURSOR FORWARD_ONLY STATIC READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID, EPOPolicyObjects.Name, EPOPolicySettings.TypeID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL != 'dummy.htm'
			AND EPOPolicyObjects.Name != 'McAfee Default';
		
		OPEN @PolicyCursor;
		
		DECLARE @PolicySettingsID INT
		DECLARE @PolicySettingsName NVARCHAR(256)
		DECLARE @PolicySettingsTypeID NVARCHAR(256)
		
		FETCH NEXT FROM @PolicyCursor INTO @PolicySettingsID, @PolicySettingsName, @PolicySettingsTypeID;
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_CreateServerPolicy @PolicySettingsID, @PolicySettingsName, @PolicySettingsTypeID, @ProductCode
		
			FETCH NEXT FROM @PolicyCursor INTO @PolicySettingsID, @PolicySettingsName, @PolicySettingsTypeID;
		END
		
		CLOSE @PolicyCursor;
		DEALLOCATE @PolicyCursor;
	END

	EXEC EPOPolicy_SetPolicySettingValue 0, @DefaultPolicySettingsID, 'ServerUpgraded', 'UpgradeHappened', 1
END

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_CreateServerPolicy]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_CreateServerPolicy]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeServer]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeServer]
GO
