IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeNonVirusPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeNonVirusPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeNonVirusPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	DECLARE @DetectSpyware INT
	DECLARE @DetectAdware INT
	DECLARE @DetectRemoteAdminTools INT
	DECLARE @DetectDialers INT
	DECLARE @DetectPasswordCrackers INT
	DECLARE @DetectJokes INT
	DECLARE @DetectPotentiallyUnwantedApps INT
	DECLARE @DetectKeyLoggers INT
	
	SELECT @SectionName = @szPlatform + 'DATDetections'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectSpyware',					@DetectSpyware OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectAdware',					@DetectAdware OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectRemoteAdminTools',			@DetectRemoteAdminTools OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectDialers',					@DetectDialers OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectPasswordCrackers',			@DetectPasswordCrackers OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectJokes',					@DetectJokes OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectPotentiallyUnwantedApps',	@DetectPotentiallyUnwantedApps OUTPUT
		EXEC EPOPolicy_GetPolicySettingValue @PolicySettingsID, @SectionName, 'DetectKeyLoggers',				@DetectKeyLoggers OUTPUT
		IF @DetectSpyware = 0 AND 
		   @DetectAdware = 0 AND
		   @DetectRemoteAdminTools = 0 AND
		   @DetectDialers = 0 AND
		   @DetectPasswordCrackers = 0 AND
		   @DetectJokes = 0 AND
		   @DetectPotentiallyUnwantedApps = 0 AND
		   @DetectKeyLoggers = 0
		BEGIN
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectSpyware', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectAdware', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectRemoteAdminTools', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectDialers', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectPasswordCrackers', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectJokes', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectPotentiallyUnwantedApps', '1'
			EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'DetectKeyLoggers', '1'
		END
	END	
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeLowRiskPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeLowRiskPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeLowRiskPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	
	/* ----------------------------------------------------------------------------
	[Trusted-Spyware]					[Trusted-Spyware]
	ApplyNVP		= 0				=>  = 1
	---------------------------------------------------------------------------- */
	SELECT @SectionName = @szPlatform + 'Trusted-Spyware'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'ApplyNVP', '1'			
	END	
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeHighRiskPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeHighRiskPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeHighRiskPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	
	/* ----------------------------------------------------------------------------
	[Untrusted-Spyware]					[Untrusted-Spyware]
	ApplyNVP		= 0				=>  = 1
	---------------------------------------------------------------------------- */
	SELECT @SectionName = @szPlatform + 'Untrusted-Spyware'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'ApplyNVP', '1'			
	END	
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeDefaultPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeDefaultPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeDefaultPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	
	/* ----------------------------------------------------------------------------
	[Default-Spyware]					[Default-Spyware]
	ApplyNVP		= 0				=>  = 1
	---------------------------------------------------------------------------- */
	SELECT @SectionName = @szPlatform + 'Default-Spyware'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'ApplyNVP', '1'			
	END	
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeGeneralPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeGeneralPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeGeneralPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	
	/* ----------------------------------------------------------------------------
	[General]							[General]
	ScanCookies		= 0				=>  = 1
	---------------------------------------------------------------------------- */
	SELECT @SectionName = @szPlatform + 'General'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'ScanCookies', '1'			
	END	
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeEmailPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeEmailPolicies]
GO

CREATE PROCEDURE dbo.VSE_UpgradeEmailPolicies
(
	@PolicySettingsID INT,
	@szPlatform NVARCHAR(50)
)
AS
BEGIN
	DECLARE @SectionName NVARCHAR (100)
	
	/* ----------------------------------------------------------------------------
	[EmailSpyware]						[EmailSpyware]
	ApplyNVP		= 0				=>  = 1
	---------------------------------------------------------------------------- */
	SELECT @SectionName = @szPlatform + 'EmailSpyware'

	IF EXISTS(SELECT *
		  FROM EPOPolicySettingValues 
		  WHERE EPOPolicySettingValues.PolicySettingsID = @PolicySettingsID
		  AND SectionName = @SectionName)
	BEGIN
		EXEC EPOPolicy_SetPolicySettingValue 0, @PolicySettingsID, @SectionName, 'ApplyNVP', '1'			
	END	
END
GO

IF EXISTS (SELECT ePOVersion FROM EPOServerInfo WHERE ePOVersion > '3.5.0')
BEGIN
	DECLARE @ProductCode NVARCHAR(30)
	
	SELECT @ProductCode = ''
	
	IF EXISTS (SELECT * FROM OrionExtensions
		       WHERE Name = 'VSEMAS870000')
	BEGIN
		SELECT @ProductCode = 'VIRUSCAN8700'
	END

	IF @ProductCode <> ''
	BEGIN
		DECLARE @PolicySettingsID INT	
		DECLARE @NonVirusCursor CURSOR;		
		SET @NonVirusCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditUnwantedProgramsPolicy.do';
		
		OPEN @NonVirusCursor;
		
		FETCH NEXT FROM @NonVirusCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeNonVirusPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeNonVirusPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @NonVirusCursor INTO @PolicySettingsID
		END
		
		CLOSE @NonVirusCursor;
		DEALLOCATE @NonVirusCursor;
		
		
		DECLARE @LowRiskCursor CURSOR;
		SET @LowRiskCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditOASLowRiskPolicy.do';
		
		OPEN @LowRiskCursor;
			
		FETCH NEXT FROM @LowRiskCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeLowRiskPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeLowRiskPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @LowRiskCursor INTO @PolicySettingsID
		END
		
		CLOSE @LowRiskCursor;
		DEALLOCATE @LowRiskCursor;
		
		
		DECLARE @HighRiskCursor CURSOR;
		SET @HighRiskCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditOASHighRiskPolicy.do';
		
		OPEN @HighRiskCursor;
			
		FETCH NEXT FROM @HighRiskCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeHighRiskPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeHighRiskPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @HighRiskCursor INTO @PolicySettingsID
		END
		
		CLOSE @HighRiskCursor;
		DEALLOCATE @HighRiskCursor;
	
	
		DECLARE @DefaultCursor CURSOR;
		SET @DefaultCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditOASDefaultPolicy.do';
		
		OPEN @DefaultCursor;
			
		FETCH NEXT FROM @DefaultCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeDefaultPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeDefaultPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @DefaultCursor INTO @PolicySettingsID
		END
		
		CLOSE @DefaultCursor;
		DEALLOCATE @DefaultCursor;
		
		
		DECLARE @GeneralCursor CURSOR;
		SET @GeneralCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditOASGeneralPolicy.do';
		
		OPEN @GeneralCursor;
			
		FETCH NEXT FROM @GeneralCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeGeneralPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeGeneralPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @GeneralCursor INTO @PolicySettingsID
		END
		
		CLOSE @GeneralCursor;
		DEALLOCATE @GeneralCursor;
		
		DECLARE @EmailCursor CURSOR;
		SET @EmailCursor = CURSOR FORWARD_ONLY READ_ONLY FOR
			SELECT EPOPolicySettings.PolicySettingsID
			FROM EPOPolicyProductToTypes, EPOPolicySettings, EPOPolicyObjects, EPOPolicyObjectToSettings
			WHERE EPOPolicyProductToTypes.TypeID = EPOPolicySettings.TypeID
			AND EPOPolicyProductToTypes.TypeID = EPOPolicyObjects.TypeID
			AND EPOPolicyObjectToSettings.PolicySettingsID =  EPOPolicySettings.PolicySettingsID
			AND EPOPolicyObjectToSettings.PolicyObjectID = EPOPolicyObjects.PolicyObjectID
			AND EPOPolicyProductToTypes.ProductCode = @ProductCode
			AND EPOPolicyProductToTypes.EditURL = 'EditEmailScanPolicy.do';
		
		OPEN @EmailCursor;
			
		FETCH NEXT FROM @EmailCursor INTO @PolicySettingsID
		WHILE (@@FETCH_STATUS = 0)
		BEGIN
			EXECUTE VSE_UpgradeEmailPolicies @PolicySettingsID, 'Server_'
			EXECUTE VSE_UpgradeEmailPolicies @PolicySettingsID, 'Wrkstn_'
		
			FETCH NEXT FROM @EmailCursor INTO @PolicySettingsID
		END
		
		CLOSE @EmailCursor;
		DEALLOCATE @EmailCursor;	
		
	END
END

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeNonVirusPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeNonVirusPolicies]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeLowRiskPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeLowRiskPolicies]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeHighRiskPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeHighRiskPolicies]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeDefaultPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeDefaultPolicies]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeGeneralPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeGeneralPolicies]
GO

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[VSE_UpgradeEmailPolicies]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[VSE_UpgradeEmailPolicies]
GO